import { Observable } from 'rxjs';
export declare class BbApiConfig {
    baseUrl: string;
    auth?: {
        endpoints?: {
            login?: string;
            logout?: string;
            refresh?: string;
            resetPassword?: string;
            requestPassword?: string;
        };
        routes: {
            redirectUrl: string;
        };
        data?: {
            role?: string;
        };
        map?: {
            login?: (data: any) => LoginResponse;
            refresh?: (data: any) => RefreshResponse;
        };
    };
    paging?: {
        request?: Partial<BbApiPageRequestFormat>;
        response?: Partial<BbApiPageResponseFormat>;
    };
}
export interface BbApiPageParameters {
    pageNumber: number;
    pageSize: number;
    query: string | null;
    queryFields: string[];
    sort: {
        name: string;
        direction: 'asc' | 'desc';
    }[];
    extra: {}[];
}
export interface BbApiPageResponse<T = any> {
    totalPages: number;
    totalEntries: number;
    pageSize: number;
    pageNumber: number;
    data: T[];
}
export interface BbApiPageRequestFormat {
    pageNumber: string;
    pageSize: string;
    sort: string;
    sortDirection: string;
    query: string;
    queryFields: string;
}
export interface BbApiPageResponseFormat {
    totalPages: string;
    totalEntries: string;
    pageSize: string;
    pageNumber: string;
    data: string;
}
export declare class BbDataSourceRequest {
    private _request$;
    readonly when: Observable<BbApiPageParameters>;
    update(params?: Partial<BbApiPageParameters>): void;
}
export declare abstract class BbApiDataSource<T = any> {
    abstract handle(request: BbDataSourceRequest): Observable<BbApiPageResponse<T>>;
}
export interface LoginResponse {
    accessToken: string;
    refreshToken: string;
    user: object;
}
export interface RefreshResponse {
    accessToken: string;
    refreshToken: string;
}
